{% extends "manage/base.html" %}

{% load i18n base_tags breadcrumbs %}

{% block breadcrumbs %}
{% breadcrumbs "Report index:" %}
{% endblock %}

{% block content %}

<h2>{% trans "Crawling reports" %}</h2>

{% include "crawler/inc.report_list.html" %}

{% endblock %}
