{% extends "block.html" %}

{% load inlinetrans %}

{% block blockbody %}
 <ul>
 {% for item in item_list %}
   <li>{{ item }}</li>
 {% empty %}
   {% itrans "There is no items in collection" %}
 {% endfor %}
 </ul>
{% endblock %}
