{% extends "manage/base.html" %}

{% load i18n %}

{% block content %}

<div id="wizard">
  {% block wizardpretitle %}
  {% endblock %}
  {% block wizardtitle %}
  <p>{% blocktrans %}Step {{ step }} of {{ step_count }}{% endblocktrans %}</p>
  {% endblock %}
  <form action="." method="post">{% csrf_token %}
    {% block wizardform %}
      {% block wizardformtext %}
      {% endblock %}
    <table>
    {{ form }}
    </table>
    {% block wizardbottom %}
      <input type="hidden" name="{{ step_field }}" value="{{ step0 }}" />
      {{ previous_fields|safe }}
      <div class="submitRow">
        <input type="submit" value="{% trans "Go to next step" %}" />
      </div>
    {% endblock %}
   {% endblock %}
  </form>
</div>

{% endblock %}
