/* See http://lesscss.org/docs */

@font-size: 1em;
@h1-font-size: 2.2em;
@h1-margin: 1em;
@h2-font-size: 1.8em;
@h2-margin: 1em;
@h3-font-size: 1.2em;
@h3-margin: 0 0 1em 0;
@soft-color: #DAE6F2;
@color: #444444; /* #fff5d6 */
@black: #717171;
@grey1: #cccccc;
@grey2: @grey1 + #111111; /* dddddd */
@grey3: @grey1 + #212121; /* ededed */
@header-height: 78px;
@border-style: 1px solid @grey1;
@linkhover:  #004080;
@linkcolor: #6c98bd;
@font-family: Georgia,"Times New Roman",Times,serif;
@header-font-family: "LeagueGothicRegular","Arial Narrow","Arial",sans-serif;
@content-left-position: 160px;

body {
    font-family: @font-family;
    font-size: @font-size;
    color: @color;
    background: #F7F7F7 none repeat scroll 0 0;
}

a {
    color: @linkcolor;
    text-decoration: none;
    :hover {
        border-bottom: 1px dotted;
        color: @linkhover;
    }
}

h1, h2, h3, h4, h5, h6 {
    font-family: @header-font-family;
    font-weight: bold;
    color: #717171;
    text-transform: uppercase;
    letter-spacing: -1px;
}

h1 {
    font-size: @h1-font-size;
}

h2 {
    font-size: @h2-font-size;
}

h3 {
    font-size: @h3-font-size;
}

div#page {
    width: 1050px;
    position: relative;
    clear: left;
}

div#container {
    -moz-box-shadow: 0 0 3px @color;
    -webkit-box-shadow: 0 0 3px @color;
    box-shadow: 0 0 3px @color;
    background-color: white;
    position: absolute;
    left: @content-left-position;
    width: 900px;

    #contentwrapper {
        padding: 1.5em;
        position: relative;
        min-height: 600px;
    }

    #contenttop {
        background: #333333 none repeat scroll 0 0;
        height: 35px;
        color: #999999;
        line-height: 2.2em;
        h1 {
            font-size: 1.2em;
            margin-left: 1.2em;
            letter-spacing: 1px;
        }
    }

    #content {
        line-height: 1.5em;
        width: 600px;

        h2:first-child {
            font-size: 2.5em;
            margin: 0 1em 0.5em 0;
            text-shadow: 1px 1px 1px #999999;
            text-transform: uppercase;
            border-bottom: 5px solid #F3F3F3;
            line-height: 50px;
        }
        p.introText {
            font-family: MunroSmallRegular,Georgia,"Times New Roman",Times,serif;
            font-size: 1.2em;
        }

        ul li {
            margin-left: 1.5em;
            list-style: square;
        }

    }

    #rightsidebar {
        background: #F1F1F1 none repeat scroll 0 0;
        position: absolute;
        right: 0;
        top: 0;
        bottom: 0;
        width: 250px;
        border-left: 2px solid #e0e0e0;
        padding: 0.5em;
    }
}

/* ----- list styles ----- */
ul li {
    margin: 0.5em;
}

dt {
    margin: 0.5em 0 0.3em 0;
    font-style: italic;
}

dd {
    margin-left: 0.5em;
}

/* ----- pagetop ----- */
#pagetop {
    margin: 0px 30px;

    .block {
        float: left;
    }
}

/* ----- leftsidebar ----- */
#leftsidebar {
    position: fixed;
    top: 200px;
    left: 0px;
    width: @content-left-position;

    h1 {
        font-size: 1.5em;
    }
}

/* ----- navigation ----- */
nav {
    ul li {
        font-family: @header-font-family;
        text-transform: uppercase;
        font-weight: bolder;
        text-align: right;
        margin-right: 1em;
        margin-bottom: 1em;
    }
}

/* ----- blocks ----- */

.rightsidebarBlock h1 {
    color: #29ABE2;
    font-size: 1.2em;
    font-family: "LeagueGothicRegular","Arial Narrow","Arial",sans-serif;
    margin: 0.5em 0;
}

/* ----- news ----- */

.newsCategory {
    margin-bottom: 1em;
}
