# Copyright (c) 2010 by Yaco Sistemas
#
# This file is part of django-player.
#
# django-player is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# django-player is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with django-player.  If not, see <http://www.gnu.org/licenses/>.


def collections(request):
    from player.data.models import Collection
    collections = {}
    for collection in Collection.objects.all():
        collections[collection.slug] = collection.item_set.all()
    return {'collections': collections}
