{% extends "manage/base.html" %}

{% load i18n breadcrumbs generic_delete content_delete %}

{% block breadcrumbs %}
  {% breadcrumbs "URLs:../" url:. %}
{% endblock %}

{% block content %}
  <h2>{% trans "URL pattern detail" %}</h2>
  <ul>
   <li><label>{% trans "Pattern" %}</label>: {{ url.pattern }}</li>
   <li><label>{% trans "Pattern type" %}</label>: {{ url.get_pattern_type_display }}</li>
   <li><label>{% trans "View" %}</label>: {{ url.view_path }}</li>
  </ul>

  <ul class="actions">
    <li><a href="{% url player.dburl.views.url_edit url.id %}">{% trans "Edit URL" %}</a></li>
    {% url url_list as next_url %}
    {% generic_delete url next_url "Delete URL" %}
  </ul>

{% endblock %}