{% if request.user.is_staff %}
{% load i18n media_tags inlinetrans block_tags %}
{% addmedia "css" %}
  <link href="{{ STATIC_URL }}base/css/toolbar.css" rel="stylesheet" type="text/css" />
{% endaddmedia %}

<div id="toolbar">
  <ul>
    <li id="toolbar-title">{% trans "Presentation Layer toolbar" %}</li>
    <li>{% inlinetrans_media %}<span id="inlinetrans-toolbar"></span>{% inlinetrans_toolbar "inlinetrans-toolbar" %}</li>
  </ul>
</div>
{% endif %}
