{% extends "admin/base.html" %}
{% load i18n %}

{% block title %}{{ title }} | {% trans 'Frontend-layer site admin' %}{% endblock %}

{% block extrahead %}
  <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}base/css/admin.css" />
{% endblock %}

{% block branding %}
<h1 id="site-name">{% trans 'Frontend-layer administration' %}</h1>
{% endblock %}

{% block nav-global %}{% endblock %}
