{% extends "base/layout.html" %}

{% load inlinetrans block_tags %}

{% block cssstyles %}
  <link rel="stylesheet" href="{{ STATIC_URL }}base/css/reset.css" type="text/css" /> 
  {% if debug %}
    <link rel="stylesheet/less" href="{{ STATIC_URL }}css/style.less" type="text/css">
    <script type="text/javascript" src="{{ STATIC_URL }}base/js/less.js"></script>
  {% else %}
    <link rel="stylesheet" href="{{ STATIC_URL }}css/style.css" type="text/css" />
  {% endif %}
{% endblock %}

{% block headscripts %}
  <script type="text/javascript" src="{{ STATIC_URL }}js/modernizr-1.7.min.js"></script>
{% endblock %}

{% block pagetop %}
<div id="pagetop">
 {% render_blocks "top" %}
</div>
{% endblock %}

{% block contenttop %}<h1>{% itrans "Welcome to django-playerlayer demo" %}</h1>{% endblock %}

{% block content %}{% endblock %}
