{% extends "base.html" %}

{% load inlinetrans pagination_tags %}

{% block content %}
<h2>{% itrans "Item listing" %}</h2>
<p class="introText">{% itrans "Here you can browse all the items from all the collections" %}</p>

{% autopaginate item_list 10 %}
<ul>
  {% for item in item_list %}
    <li><a href="./{{ item.id }}" title="{{ item }}">{{ item }}</a></li>
  {% endfor %}
</ul>
<div class="paginator">{% paginate %}</div>
{% endblock %}