body {
  font-family: Georgia, "Times New Roman", Times, serif;
  font-size: 1em;
  color: #444444;
  background: #F7F7F7 none repeat scroll 0 0;
}
a {
  color: #6c98bd;
  text-decoration: none;
}
a :hover {
  border-bottom: 1px dotted;
  color: #004080;
}
h1,
h2,
h3,
h4,
h5,
h6 {
  font-family: "LeagueGothicRegular", "Arial Narrow", "Arial", sans-serif;
  font-weight: bold;
  color: #717171;
  text-transform: uppercase;
  letter-spacing: -1px;
}
h1 {
  font-size: 2.2em;
}
h2 {
  font-size: 1.8em;
}
h3 {
  font-size: 1.2em;
}
div#page {
  width: 1050px;
  position: relative;
  clear: left;
}
div#container {
  -moz-box-shadow: 0 0 3px #444444;
  -webkit-box-shadow: 0 0 3px #444444;
  box-shadow: 0 0 3px #444444;
  background-color: white;
  position: absolute;
  left: 160px;
  width: 900px;
}
div#container #contentwrapper {
  padding: 1.5em;
  position: relative;
  min-height: 600px;
}
div#container #contenttop {
  background: #333333 none repeat scroll 0 0;
  height: 35px;
  color: #999999;
  line-height: 2.2em;
}
div#container #contenttop h1 {
  font-size: 1.2em;
  margin-left: 1.2em;
  letter-spacing: 1px;
}
div#container #content {
  line-height: 1.5em;
  width: 600px;
}
div#container #content h2:first-child {
  font-size: 2.5em;
  margin: 0 1em 0.5em 0;
  text-shadow: 1px 1px 1px #999999;
  text-transform: uppercase;
  border-bottom: 5px solid #F3F3F3;
  line-height: 50px;
}
div#container #content p.introText {
  font-family: MunroSmallRegular,Georgia,"Times New Roman",Times,serif;
  font-size: 1.2em;
}
div#container #content ul li {
  margin-left: 1.5em;
  list-style: square;
}
div#container #rightsidebar {
  background: #F1F1F1 none repeat scroll 0 0;
  position: absolute;
  right: 0;
  top: 0;
  bottom: 0;
  width: 250px;
  border-left: 2px solid #e0e0e0;
  padding: 0.5em;
}
ul li {
  margin: 0.5em;
}
dt {
  margin: 0.5em 0 0.3em 0;
  font-style: italic;
}
dd {
  margin-left: 0.5em;
}
#pagetop {
  margin: 0px 30px;
}
#pagetop .block {
  float: left;
}
#leftsidebar {
  position: fixed;
  top: 200px;
  left: 0px;
  width: 160px;
}
#leftsidebar h1 {
  font-size: 1.5em;
}
nav ul li {
  font-family: "LeagueGothicRegular", "Arial Narrow", "Arial", sans-serif;
  text-transform: uppercase;
  font-weight: bolder;
  text-align: right;
  margin-right: 1em;
  margin-bottom: 1em;
}
.rightsidebarBlock h1 {
  color: #29ABE2;
  font-size: 1.2em;
  font-family: "LeagueGothicRegular", "Arial Narrow", "Arial", sans-serif;
  margin: 0.5em 0;
}
.newsCategory {
  margin-bottom: 1em;
}