.blockContainerBorder {
    /* border-radius */
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    border-radius: 5px;
    /* box-shadow */
    -webkit-box-shadow: #808080 0px 0px 10px;
    -moz-box-shadow: #808080 0px 0px 10px;
    box-shadow: #808080 0px 0px 10px;
}

.blockContainer .block {

}

.blockContainer .block .blockTools {
    float: left;
    position: absolute;
    display: none;
}

.blockContainer .block .blockTools a {
    width: 20px;
    height: 25px;
    display: block;
}

.blockContainer .block .blockTools a.drag {
    background: transparent url("../img/arrow_refresh.png") no-repeat 0px 5px;
}

.blockContainer .block .blockTools a.configure {
    background: transparent url("../img/configure.png") no-repeat 0px 0px;
}

.blockContainer .blockDrag {
    color: #999;
    font-style: italic;
    padding: 2px;
    font-size: 1em;
}

.configDebug {
    display: none;
}

#config-block form#config-block-form label {
    color: #ABABAB;
    font-size: 1.2em;
}

#config-block form#config-block-form div.config_params_container {
    border: 1px solid #EEE;
    padding: 6px 12px;
    margin-top: 5px;
} 

#config-block form#config-block-form div.config_params_container label {
    font-size: 13px;
    color: #737373;
    float: left;
    margin-right: 1em;
    font-weight: normal;
}

#config-block form#config-block-form div.config_params_container input {
    margin-left: 0.5em;
}

#config-block form#config-block-form div.submit {
    margin: 0.5em;
    text-align: center;
}

#block-toolbar .active {
    background-color: #BFBFBF;
}

