{% extends "manage/base.html" %}
{% load i18n base_tags breadcrumbs %}

{% block breadcrumbs %}
  {% breadcrumbs "Staging:../../" "Create repository from server:" %}
{% endblock %}

{% block content %}
  <h2>{% trans "Create repository from server" %}</h2>

  <form action="." method="post">{% csrf_token %}
    {{ form.as_p }}
    <input class="button" type="submit" value="{% trans "Create repository" %}" />
  </form>
{% endblock %}
