{% extends "manage/base.html" %}
{% load i18n breadcrumbs %}

{% block breadcrumbs %}
{% breadcrumbs "URLs:" %}
{% endblock %}

{% block content %}
    <h2>{% trans "URLs stored in Presentation Layer" %}</h2>

    {% if url_list %}
    <table class="listing">
        <thead>
        <th>{% trans "Pattern" %}</th><th>{% trans "Pattern type" %}</th><th>{% trans "View" %}</th>
        </thead>
        <tbody>
        {% for url in url_list %}
        <tr>
        <td><a href="{% url url_detail url.id %}" title="{{ url }}">{{ url.pattern }}</a></td>
        <td class="centered">{{ url.get_pattern_type_display }}</td>
        <td class="centered">{{ url.view_path }}</td>
        </tr>
        {% endfor %}
        </tbody>
    </table>
    {% else %}
    <p>{% trans "There are no URLs managed yet" %}</p>
    {% endif %}

    <ul class="actions">
      <li><a href="{% url player.dburl.views.url_add %}">{% trans "Add a new URL" %}</a></li>
    </ul>
{% endblock %}
