div.config_params_debug_container,
div.config_params_container {
    float: left;
    margin-right: 1em;
    margin-left: 1em;
}

div.config_params_debug_container {
    border-left: 1px solid gray;
    padding-left: 2em;
}

div.config_params_debug_container label,
div.config_params_container label {
    display: block;
    float: none;
    margin-bottom: 0.5em;
    width: auto;
}

.configDebug {
    clear: both;
}
