{% extends "forms/wizard.html" %}

{% load i18n breadcrumbs %}

{% block breadcrumbs %}
{% breadcrumbs "Collection groups:../../../../../" collection.collectiongroup collection "Map collection:." %}
{% endblock %}

