{% extends "base.html" %}

{% load inlinetrans %}

{% block content %}
  <h2>{% itrans "Presentation Layer website" %}</h2>
  <p>{% itrans "This is a newly created Django website, using Django Presentation Layer framework" %}</p>
{% endblock %}