/* See http://lesscss.org/docs */

@h1-font-size: 2.6em;
@h1-margin: 1em;
@h3-font-size: 1.3em;
@h3-margin: 0 0 1em 0;
@soft-color: #DAE6F2;
@color: @soft-color - #000515; /* #fff5d6 */
@black: #717171;
@grey1: #cccccc;
@grey2: @grey1 + #111111; /* dddddd */
@grey3: @grey1 + #212121; /* ededed */
@header-height: 78px;
@border-style: 1px solid @grey1;
@redpastel: #ff4848;
@linkhover:  #004080;
@linkcolor: #6c98bd;
@orange: #D1975A;

body {
    font-family: Arial, Helvetica, sans-serif;
    font-size: 12px;
    color: #717171;
}

a {
    color: @linkcolor;
    text-decoration: none;
    :hover {
        border-bottom: 1px dotted;
        color: @linkhover;
    }
}

th {
    font-weight: normal;
}

pre, code {
    font-size: 90%;
}

code {
    display: block;
    background: #eeeeee none repeat scroll 0 0;
    border: 1px solid #cccccc;
    padding: 10px;
    white-space: pre;
}

.actionRow {
    text-align: right;
}

.hidden {
    display: none;
}

#login 
{
     width: 350px;
     margin: 100px auto;
     border: 1px solid @grey1;
     background-color: @soft-color;
     padding: 20px;
     /* border-radius */
     -webkit-border-radius: 8px;
     -moz-border-radius: 8px;
     border-radius: 8px;

    label {
        text-align: right;
        float: left;
        width: 150px;
        margin-right: 5px;
    }

    p {
        margin-bottom: 10px;
    }

    form {
        margin-top: 150px;
    }
}

/* Layout */
/* Ripped off http://www.maxdesign.com.au/articles/css-layouts/three-liquid/ */

#container 
{
    margin: 0 auto;
    width: 100%;

    #header 
    {
        height: @header-height;
        background: @soft-color;
        border-bottom: 2px solid @grey2;

        h1 {
            font-size: @h1-font-size;
            margin-bottom: @h1-margin;

            a {
                height: @header-height;
                width: 142px;
                text-indent: -10em;
                display: block;
            }
        }

        #usertools 
        {
            float: right;
            padding: 30px 45px 0 0;
        }
    }


    #breadcrumbs 
    {
        padding: 20px 0px 0px;
        height: 10px;
        line-height: 1.3em;
        font-size: 1em;
        color: @linkcolor;

        ul {
            li {
                display: inline;
            }
        }
    }

    #content 
    {
        float: left;
        width: 70%;
        font-size: 100%;
        min-height: 500px;
        padding: 10px 0 0 20px;
        margin-bottom: 20px;

        .message {
            float: right;
            margin-top: 5px;
            div {
                p {
                    padding: 0 1em;
                }
            }
        }

        h1 {
            font-size: @h1-font-size;
            margin-top: @h1-margin;
            margin-bottom: @h1-margin;
        }

        h2 {
            font-size: @h1-font-size * 0.6539;
            margin-top: @h1-margin * 0.7;
            margin-bottom: @h1-margin * 0.5;
        }

        h3 {
            font-size: @h1-font-size * 0.5;
            margin-top: @h1-margin * 0.7;
            margin-bottom: @h1-margin * 0.5;
        }

        label {
            font-style:italic;
        }

        label.mandatory {
            font-weight:bold;
        }

        a {
            color: @linkcolor;
        }

        a.headerLink {
            color: #D0ADFF;
            font-size: 0.9em;
            display: none;
            padding: 0 4px;
        }

        .ui-widget-header li a {
            color: #222222;
        }

        :hover > a.headerLink {
            display: inline;
        }

        p {
            margin: 20px 0 10px 0;
        }

        form {
            background-color: #F0F5FA;
            padding: @h1-margin;
            -webkit-border-radius: 8px;
            -moz-border-radius: 8px;
            border-radius: 8px;
            margin: 20px 0 10px 0;

            input.button {
                width: auto;
            }

            .actionRow {
                text-align: center;
            }

            .removeRow {
                position: relative;
                top: -5.1em;
                float: left;
            }
            #no-relative.removeRow
            {
                position: static;
            }
            .submitRow {
                text-align: center;
                margin-top: @h1-margin;
            }

            label, th {
                text-align: right;
                margin-right: 10px;
                min-width: 7em;
                line-height: 2em;
                font-style: normal;
            }
            table.CollectionFieldsTable th {
                text-align: left;
            }
        }
        ul.ui-tabs-nav li.ui-state-hover a {
            border-bottom: none;
            :hover {
            border-bottom: none;
            }
        }
        .pagination {
            width: 60%;
            text-align: center;
            margin: 1em 0;
            .page {
                border: @border-style;
                padding: 0 6px;
                line-height: 18px;
                margin-left: 2px;
            }
            .prev {
                background: transparent url(../img/prev_bg.jpg) top left no-repeat;
                font-size: 92%;
                height: 18px;
                width: 78px;
                float: left;
                display: block;
                padding: 2px 0 0 8px;
                margin-right: 1em;
                text-align:left;
            }
            .next {
                background: transparent url(../img/next_bg.jpg) top right no-repeat;
                font-size: 92%;
                height: 18px;
                width: 78px;
                float: right;
                display: block;
                padding: 2px 4px;
                margin-left: 1em;
                text-align:right;
            }
            .current {
                background-color: #81A2CC;
                border-color: #81A2CC;
                color: white;
            }
            a:hover {
                border-bottom: none;
            }
            .disabled {
                color: @grey1;
            }
        }
        .collectionState {
            h3 {
                color: @orange;
                font-size: @h1-font-size * 0.5;
                line-height: 2em;
                padding-left: 1em;
                margin: 2px;
            }

            ul, ol {

                padding: 0 1em 0 0;
                margin: 0;
                list-style: none;

                a {
                    color: @orange;
                    text-decoration: underline;
                }

                li {
                    padding-left: 4.5em;
                    margin-top: 2em;
                    background-position: 10px top;
                    background-repeat: no-repeat;

                    p {
                        padding-left: 1em;
                        line-height: 1.5em;
                        margin: 0.5em;
                    }

                    form {
                        padding: 0.5em 1.5em;
                    }
                }


                h4 {
                    font-weight: bold;
                    border-bottom: 1px solid @grey1;
                    line-height: 1.5em;
                    a {
                        color: @black;
                        text-decoration: none;
                    }
                }

                li.finished {
                    background-image: url(../img/step-done.png);
                }

                li.unfinished {
                    background-image: url(../img/step-undone.png);
                }

            }

            #collection-steps
              {

                li.stepOne {
                    background-image: url(../img/step-one.png);
                }

                li.stepTwo {
                    background-image: url(../img/step-two.png);
                }

                li.stepThree {
                    background-image: url(../img/step-three.png);
                }

                li.stepFour {
                    background-image: url(../img/step-four.png);
                }
            }

        }
        .listing {
            width: 80%;
            background-color: #fff;

            caption {
            font-style: italic;
            line-height: 3em;
            }

            thead {
                border: @border-style;
            }

            tbody {
                border: @border-style;
                padding: 5px;
            }

            th {
                line-height: 2em;
                background-color: @soft-color;

            }

            tr.even td {
                background-color: #f3f3f3;
            }

            td {
                line-height: 1.5em;
                padding: 5px;
            }
        }
        .crawlermapping {
            th {
                padding-right: 1em;
            }
        }
        ul {
            list-style-type: square;
        }
        ol {
            list-style-type: decimal;
        }
        ul, ol {
            padding-left: 2em;
            li {
                line-height: 1.5em;
                a:hover {
                    border-bottom: 1px dotted;
                    color: @linkhover;
                }
            }
        }
        ul.actions {
            margin-top: 2em;
            li {
                margin: 5px;
                cursor: pointer;
                text-align: center;
                display: inline;
                a,
                input {
                    border: 1px solid @grey1;
                    width: 100%;
                    padding: 5px 6px;
                    background: @grey3;
                    border-radius: 2px;
                    -webkit-border-radius: 2px;
                    -moz-border-radius: 2px;
                    -webkit-box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
                    -moz-box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
                    box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);                    
                    font-size: @h1-margin;
                    text-shadow: 1px 1px 0 white;
                    :hover {
                        background: transparent;
                        border-bottom: 1px dotted;
                    }
                }
                input {
                    width: auto;
                }
            }
            li.disabled a {
                background-color: #DFDFDF;
                color: gray;
            }
            input {
                background: transparent;
                border: none;
                color: @linkcolor;
            }
            :hover {
                color: @linkhover;
                cursor: hand;
            }
        }
        ul.messages  {
            list-style: none;
            padding: 0;
            margin: 0.5em 0;
            li {
                padding: 0.5em;
            }
            li.success {
                background-color: #DEFFDA;
                border: 1px solid #68e157;
            }
            li.warning {
                background-color: #ffdd55;
                border: 1px solid #ffaa00;
                color: black;
            }
            li.error {
                background-color: @redpastel;
                border: 1px solid red;
                color: white;
            }
        }
        dt {
            font-weight: bold;
        }
        dd {
            padding: 0.5em 0 1em 2em;
        }
        .centered {
            text-align: center;
        }
        #item-deleted 
        {
            padding: 10px;
            color: white;
            background: @redpastel;
        }
        .CollectionFields {
            margin-bottom: 50px;
        }
        table {
            margin-bottom: 10px;
        }
    }

    #left-sidebar 
    {
        display: inline;
        float: left;
        width: 12%;
        padding: 20px 20px 0;

        h3 {
            font-size: @h3-font-size;
            margin: @h3-margin;
        }

        .menu {
            margin-bottom: 20px;

            li {
                margin: 5px;
                border: 1px solid @grey1;
                cursor: pointer;
                padding: 5px 6px;
                text-align: center;
                background: @grey3;
                -webkit-border-radius: 2px;
                -moz-border-radius: 2px;
                border-radius: 2px;
                -webkit-box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
                -moz-box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
                box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
                a {
                    width: 100%;
                    text-shadow: 1px 1px 0 white;
                    font-size: @h1-margin;
                    :hover {
                        border: 0 solid white;
                    }
                }
                :hover {
                    background: @grey3;
                    color: @linkhover;
                }
            }
        }

        ul li {
            font-size: 1.2em;
        }

        ul ul li {
            font-size: 1.2em;
        }
    }

    #footer 
    {
        clear: both;
        background: @grey2;
        text-align: center;
        padding: 20px;
        height: 1%;
        border-top: 2px solid @grey1;
    }
    
    .configField {
        margin-bottom: 2em;
    }
}

li a:hover {
    border: none;
}

.required,
tr.required th{
    font-weight: bold;
}

.error {
    color: red;
}

.errorlist {
    border: 1px solid red;
    background: @redpastel;
    padding: 5px;
    color: white;
    font-weight: bold;
}

.mapping_field input {
    max-width: 150px;
}

.mapping_field {
    margin-bottom: 10px;
}

.mapping_field p {
    margin: 0px !important;
}

.code {
    display: inline;
}

a.changeLink {
    background: transparent url("../img/editlink_icon.png") no-repeat right top;
    margin-left:5px;
    padding-right:20px;
}


/* ----- code mirror textarea javascript editor ----- */

div.CodeMirror-wrapping {
    background-color: #fafaff;
    margin-left: 20px;
    border: 1px solid #CCCCCC;
}