{% extends "manage/base.html" %}
{% load i18n breadcrumbs %}

{% block breadcrumbs %}
{% breadcrumbs "Staging:" %}
{% endblock %}

{% block content %}
    <h2>{% trans "Staging servers" %}</h2>

    {% if server_list %}
    <table class="listing">
        <thead>
        <th>{% trans "Name" %}</th><th>{% trans "Hostname" %}</th>
        </thead>
        <tbody>
        {% for server in server_list %}
        <tr>
        <td><a href="{% url server_detail server.id %}" title="{{ server.name }}">{{ server.name }}</a></td>
        <td class="centered">{{ server.hostname }}</td>
        </tr>
        {% endfor %}
        </tbody>
    </table>
    {% else %}
    <p>{% trans "There are no servers managed yet" %}</p>
    {% endif %}

    <ul class="actions">
      <li><a href="{% url player.player_staging.views.server_add %}">{% trans "Add a new server" %}</a></li>
    </ul>
{% endblock %}
