{% load i18n %}
<div class="breadcrumbs">
  <ul class="breadcrumbs">
  {% for item in items %}
    <li{% if forloop.first %} class="first-breadcrumbs previous"{% else %}{% if not forloop.last %} class="previous"{% endif %}{% endif %}>{{ item.name|capfirst }}
    {% if forloop.first %}
      <a href="{% url player.manage.views.index %}">{{ item.title }}</a> <span class="breadcrumbs-separator">»</span>
    {% else %}
      {% if item.max_words %}
        <a href="{{ item.url }}">{{ item.title|truncatewords:item.max_words }}</a>{% if not forloop.last %} <span class="breadcrumbs-separator">»</span>{% endif %}
      {% else %}
        <a href="{{ item.url }}">{{ item.title }}</a>{% if not forloop.last %} <span class="breadcrumbs-separator">»</span>{% endif %}
      {% endif %}
    {% endif %}
    </li>
  {% endfor %}
  </ul>
</div>
