/**
 * The default CSS theme for Shadowbox.
 *
 * This file is part of Shadowbox.
 *
 * Shadowbox is an online media viewing application that supports all of the
 * most popular web publishing formats. Shadowbox is written entirely in
 * JavaScript and CSS and is highly customizable.
 *
 * Shadowbox is released under version 3.0 of the Creative Commons Attribution-
 * Noncommercial-Share Alike license. This means that it is absolutely free
 * for personal, noncommercial use provided that you 1) make attribution to the
 * author and 2) release any derivative work under the same or a similar
 * license.
 *
 * If you wish to use Shadowbox for commercial purposes, licensing information
 * can be found at http://mjijackson.com/shadowbox/.
 *
 * @author      Michael J. I. Jackson <mjijackson@gmail.com>
 * @copyright   2007-2008 Michael J. I. Jackson
 * @license     http://creativecommons.org/licenses/by-nc-sa/3.0/
 * @version     SVN: $Id$
 */

/*_________________________________________________________________  overlay  */
#shadowbox_overlay {
  visibility: hidden;
  position: absolute;
  display: block;
  margin: 0;
  padding: 0;
  top: 0;
  left: 0;
  z-index: 998;
}

/*_______________________________________________________________  container  */
#shadowbox_container {
  position: fixed;
  height: 0px;
  width: 100%;
  margin: 0;
  padding: 0;
  top: 0;
  left: 0;
  z-index: 999;
  text-align: center; /* centers in quirks and IE */
}

/*_______________________________________________________________  shadowbox  */
#shadowbox {
  display: none;
  visibility: hidden;
  margin: 0 auto;
  position: relative;
  text-align: left; /* reset left alignment */
  color: #fff;
/*  background-color: #000;*/
  border-bottom: 10px solid white;
}

/*___________________________________________________________________  title  */
/*
HTML snapshot:
<div id="shadowbox_title">
  <div id="shadowbox_title_inner">Title Here</div>
</div>
*/
#shadowbox_title {
  padding-left: 0;
  overflow: hidden;
  background: white;
}

#shadowbox_title_close {
    float: right;
    margin: 0.5em 1em 0 0;
    background: white;
}

#shadowbox_title a{
    text-decoration: none;
}

#shadowbox_title_inner {
  font-family: 'Lucida Grande', Tahoma, sans-serif;
  font-size: 22px;
  text-align:center;
  line-height: 16px;
  padding: 8px 5px 5px 10px;
  color: #777777;
  background: white;
}

/*____________________________________________________________________  body  */
/*
HTML snapsnot:
<div id="shadowbox_body">
  <div id="shadowbox_body_inner">
    <img src="my_image.jpg" id="shadowbox_content" height="350" width="580">
  </div>
  <div id="shadowbox_loading">
    <img src="images/loading.gif" alt="loading"></div>
    <span><a href="javascript:Shadowbox.close();">Cancel</a></span>
  </div>
</div>
*/
#shadowbox_body {
  position: relative;
  overflow: hidden;
/*  margin: 0;*/
/*  padding: 0;*/
  border: 10px solid #fff;
  background-color: #fff;
  color: #888888; 
}
#shadowbox_body_inner {
  position: relative;
  overflow: hidden;
}
#shadowbox_loading {
  position: absolute;
  top: 0;
  left: 0;
  height: 10000px; /* overflow:hidden will clip this */
  width: 100%;
  background-color: #060606;
}
#shadowbox_loading img {
  float: left;
  margin: 10px 10px 0 10px;
}
#shadowbox_loading span {
  font-family: 'Lucida Grande', Tahoma, sans-serif;
  font-size: 10px;
  float: left;
  margin-top: 16px;
}
#shadowbox_loading span a:link,
#shadowbox_loading span a:visited {
  color: #fff;
  text-decoration: underline;
}
#shadowbox_content.html { /* make html content scrollable */
  height: 100%;
  width: 100%;
  overflow: auto;
}

/*_________________________________________________________________  toolbar  */
/*
HTML snapshot:
<div id="shadowbox_toolbar">
  <div id="shadowbox_toolbar_inner">
    <div id="shadowbox_nav_close" class="shadowbox_nav">
      <a onclick="Shadowbox.close();" title="Close" style="background-image: url(close.png); background-repeat: no-repeat;"></a>
    </div>
    <div id="shadowbox_nav_next" class="shadowbox_nav">
      <a onclick="Shadowbox.next();" title="Next" style="background-image: url(next.png); background-repeat: no-repeat;"></a>
    </div>
    <div id="shadowbox_nav_previous" class="shadowbox_nav">
      <a onclick="Shadowbox.previous();" title="Previous" style="background-image: url(previous.png); background-repeat: no-repeat;"></a>
    </div>
    <div id="shadowbox_counter">
      <a href="javascript:Shadowbox.change(0);">1</a>
      <a href="javascript:Shadowbox.change(1);" class="shadowbox_counter_current">2</a>
      <a href="javascript:Shadowbox.change(2);">3</a>
    </div>
  </div>
</div>
*/

#shadowbox_toolbar {
/* margin: 0; */
  padding:0;
 /* padding-bottom: 5px;*/
/*   overflow: hidden; */
  width:100%;
  border-collapse:collapse;
}

#shadowbox_toolbar .shadowbox_nav_caption {
  padding: 0px 10px;
  text-align: left;
  color: #AFAFAF;
  background-color: white;
  font-weight: bold;
}

#shadowbox_toolbar_inner {
  font-family: 'Lucida Grande', Tahoma, sans-serif;
  font-size: 12px;
  color: #000;
  background-color: white;
  height: 30px;
  margin: 0 ;
}

#shadowbox_toolbar_inner span {
  vertical-align: middle;
}

#shadowbox_nav_buttons {
  text-align: right;
}

#shadowbox_toolbar_inner span span.shortcut {
  text-decoration: underline;
  font-weight: bold;
  display: inline;
}

#shadow_conter{
    padding-left: 10px;
}

#shadowbox_counter {
    margin-top: 10px;
    padding-top: 0px;
}

#shadowbox_counter a {
    border-right: 2px solid #dddddd;
    border-top: 2px solid #dddddd;
    margin-right: 4px;
}

#shadowbox_counter a:visited,
#shadowbox_counter a:hover,
#shadowbox_counter a,
#shadowbox_toolbar_inner span a {
  text-decoration: none;
  color: #3fb2c9;
}



.shadowbox_nav {
  float: right;
  display: inline;
  margin-left: 3px;
}

.shadowbox_nav_close {
  float:right;
  margin-top: 2px;
  margin-left: 20px;
}

#shadowbox_nav_buttons{
  padding-right: 10px;
  float:right;
  width: 130px;
}


.shadowbox_nav a {
  display: block;
  height: 16px;
  width: 16px;
  cursor: pointer;
}
#shadowbox_counter a {
  padding: 2px 4px 0 0;
  cursor: pointer;
}
#shadowbox_counter a.shadowbox_counter_current {
  text-decoration: underline;
  color: #a6a6a6;
  border: none;
}

/*________________________________________________________________  messages  */
div.shadowbox_message {
  font-family: 'Lucida Grande', Tahoma, sans-serif;
  font-size: 12px;
  padding: 10px;
  text-align: center;
}
div.shadowbox_message a:link,
div.shadowbox_message a:visited {
  color: #fff;
  text-decoration: underline;
}
