<div id="{{ block_name }}"
     class="{{ place }}Block block">
 {% block blocktitle %}
   <h1>{{ block_title }}</h1>
 {% endblock %}
 <span class="blockHiddenTitle">{{ block_title }}</span>
 <div class="blockBody">
 {% block blockbody %}
   {# to override #}
 {% endblock %}
 </div>
 <input type="hidden" value="{{ placed_block.id }}" class="blockId" />
</div>
