{% extends "admin/change_form.html" %}
{% load i18n base_tags %}

{% block after_field_sets %}
<div class="module aligned">
  <div class="form-row">
    <label class="required">{% trans "Schema" %}</label>
    <pre>{{ original.schema|json_format }}</pre>
  </div>
</div>
{% endblock %}
