{% extends "manage/base.html" %}

{% load i18n breadcrumbs generic_delete content_delete %}

{% block breadcrumbs %}
  {% breadcrumbs "Staging:../" "Log:" %}
{% endblock %}

{% block content %}
  <h2>{% trans "History of changes" %}</h2>
  <ul>
   {% for log in commits %}
   <li><label><a href="{{ log.changeset|urlencode }}">{{ log.changeset }}</a></label>:
   <pre>{{ log.log }}</pre></li>
   {% empty %}
   <li><label>{% trans "No changes registered" %}</label></li>
   {% endfor %}
  </ul> 


{% endblock %}
