{% extends "manage/base.html" %}
{% load i18n base_tags breadcrumbs generic_delete %}

{% block breadcrumbs %}
{% breadcrumbs "Collection groups:../../../" collection.collectiongroup collection "Last report:../" "Crawled data:" %}
{% endblock %}


{% block content %}
    {% head "Crawled raw data" %}
    {% if report.crawled_data %}
        <pre class="code">{{ report.crawled_data }}</pre>
    {% else %}
        {% trans "There is no crawled data" %}
    {% endif %}
{% endblock %}
