{% extends "manage/base.html" %}
{% load i18n %}
{% block page %}

<script type="text/javascript">
 $(document).ready(function() {
    $('#id_username').focus()
 });
</script> 

<div id="login">
  <form method="post" action="{% url auth_login %}">
  {{ form.as_p }}
  <p class="actionRow">
  <input type="hidden" name="next" value="{{ next }}" />
  <input type="submit" value="{% trans "Login" %}" />
  </p>
  {% csrf_token %}
  </form>
</div>
{% endblock %}
