{% extends "data/data_wizard.html" %}

{% load i18n %}

{% block wizardformtext %}
<p>
  {% blocktrans %}
  If you continue the remapping proccess will be completed and <b>all current items for this collection will be deleted</b>.
  {% endblocktrans %}
</p>
{% endblock %}
