{% extends "manage/base.html" %}
{% load i18n %}

{% block breadcrumbs %}{% endblock %}

{% block content %}
<h1>{% trans "Index page" %}</h1>

<p>{% trans "Welcome to Presentation Layer system." %}</p>

<h2>{% trans "Non published collections" %}</h2>
{% include "data/inc.collection_list.html"%}

<h2>{% trans "Error crawling reports" %}</h2>
{% include "crawler/inc.report_list.html" %}

{% endblock %}
