{% load i18n %}
{% if content_id %}
<li class="remove">
<a class="remove-trigger" href="">{{ link_title }}</a>
<form style="display: none;" class="remove-form" method="post" action="{{ action }}">{% csrf_token %}
<input type="hidden" name="content_id" value="{{ content_id }}"/>
<input type="hidden" name="content_type_id" value="{{ content_type_id }}"/>
{% if next_url %}<input type="hidden" name="next_url" value="{{ next_url }}"/>{% endif %}


<div class="confirm-message" title="{{ title_message }}" style="font-size: 1.2em; padding: 2em 1em;">
  <p>{{ confirmation_message }}</p>
</div>

<span class="delete-ok">{% trans "Yes, I am sure" %}</span>
<span class="delete-cancel">{% trans "Cancel" %}</span>
</form>
</li>
{% endif %}
