{% load i18n %}
<span id="{{ head_id }}"></span>
<{{ head_type }}>{% trans heading %}
<a title="{% trans "Permalink to this headline" %}" href="#{{ head_id }}" class="headerLink">¶</a>
</{{ head_type }}>