{% load i18n %}
<div id="config-block">
  <form id="config-block-form" method="POST" action="{% url generate_blocks_configuration placed_block.id %}">{% csrf_token %}
    {{ form }}
    <input type="hidden" name="blockid" value="{{ placed_block.id }}" />
    <input type="hidden" name="blockname"
           value="{{ block.name }}" />
    <div class="submit">
      <input type="submit" value="{% trans "Save configuration" %}" />
    </div>
  </form>
</div>
