{% extends "data/data_wizard.html" %}

{% load i18n %}

{% block wizardform %}

<table class="crawlermapping">
  <tr><th>{% trans "Parser" %}</th><th>{% trans "Scraping tool" %}</th></tr>
  {{ form }}
</table>
{% block wizardbottom %} {{ block.super }} {% endblock %}
{% endblock %}
