{% extends "manage/base.html" %}

{% load i18n breadcrumbs generic_delete content_delete %}

{% block breadcrumbs %}
  {% breadcrumbs "Templates:../" template:. %}
{% endblock %}

{% block content %}
  <h2>{% trans "Template detail" %}</h2>
  <ul>
   <li><label>{% trans "Name" %}</label>: {{ template.name }}</li>
   <li><label>{% trans "Creation date" %}</label>: {{ template.creation_date }}</li>
   <li><label>{% trans "Last changed" %}</label>: {{ template.last_changed }}</li>
   <li><label>{% trans "Content" %}</label>:
   <pre>{{ template.content }}</pre></li>
  </ul> 

  <ul class="actions">
    <li><a href="{% url player.dbtemplate.views.template_edit template.id %}">{% trans "Edit template" %}</a></li>
    {% url template_list as next_url %}
    {% generic_delete template next_url "Delete template" %}
  </ul>

{% endblock %}