{% extends "manage/base.html" %}
{% load i18n breadcrumbs %}

{% block breadcrumbs %}
{% breadcrumbs "Collections:" %}
{% endblock %}

{% block content %}
    <h2>{% trans "CollectionGroups managed by Presentation Layer" %}</h2>
    {% include "data/inc.collection_list.html"%}
    <ul class="actions">
      <li><a href="{% url player.data.views.collection_list %}add/">{% trans "Add a new collection" %}</a></li>
    </ul>
{% endblock %}
