body {
  font-family: Arial, Helvetica, sans-serif;
  font-size: 12px;
  color: #717171;
}
a {
  color: #6c98bd;
  text-decoration: none;
}
a:hover {
  border-bottom: 1px dotted;
  color: #004080;
}
th { font-weight: normal; }
pre, code { font-size: 90%; }
code {
  display: block;
  background: #eeeeee none repeat scroll 0 0;
  border: 1px solid #cccccc;
  padding: 10px;
  white-space: pre;
}
.actionRow { text-align: right; }
.hidden { display: none; }
#login {
  width: 350px;
  margin: 100px auto;
  border: 1px solid #cccccc;
  background: #dae6f2 url("../img/logo_login.jpg") 50% 10% no-repeat;
  padding: 20px;
  -webkit-border-radius: 8px;
  -moz-border-radius: 8px;
  border-radius: 8px;
}
#login label {
  text-align: right;
  float: left;
  width: 150px;
  margin-right: 5px;
}
#login p { margin-bottom: 10px; }
#login form { margin-top: 150px; }
#container {
  margin: 0 auto;
  width: 100%;
}
#container #header {
  height: 78px;
  background: #dae6f2;
  border-bottom: 2px solid #dddddd;
}
#container #header h1 {
  font-size: 2.6em;
  margin-bottom: 1em;
}
#container #header h1 a {
  background: transparent url(../img/logo_header.jpg) top left no-repeat;
  height: 78px;
  width: 142px;
  text-indent: -10em;
  display: block;
}
#container #header #usertools {
  float: right;
  padding: 30px 45px 0 0;
}
#container #breadcrumbs {
  padding: 20px 0px 0px;
  height: 10px;
  line-height: 1.3em;
  font-size: 1em;
  color: #6c98bd;
}
#container #breadcrumbs ul li { display: inline; }
#container #content {
  float: left;
  width: 70%;
  font-size: 100%;
  min-height: 500px;
  padding: 10px 0 0 20px;
  margin-bottom: 20px;
}
#container #content .message {
  float: right;
  margin-top: 5px;
}
#container #content .message div p { padding: 0 1em; }
#container #content h1 {
  font-size: 2.6em;
  margin-top: 1em;
  margin-bottom: 1em;
}
#container #content h2 {
  font-size: 1.70014em;
  margin-top: 0.7em;
  margin-bottom: 0.5em;
}
#container #content h3 {
  font-size: 1.3em;
  margin-top: 0.7em;
  margin-bottom: 0.5em;
}
#container #content label { font-style: italic; }
#container #content label.mandatory { font-weight: bold; }
#container #content a { color: #6c98bd; }
#container #content a.headerLink {
  color: #d0adff;
  font-size: 0.9em;
  display: none;
  padding: 0 4px;
}
#container #content .ui-widget-header li a { color: #222222; }
#container #content:hover > a.headerLink { display: inline; }
#container #content p { margin: 20px 0 10px 0; }
#container #content form {
  background-color: #f0f5fa;
  padding: 1em;
  -webkit-border-radius: 8px;
  -moz-border-radius: 8px;
  border-radius: 8px;
  margin: 20px 0 10px 0;
}
#container #content form input.button { width: auto; }
#container #content form .actionRow { text-align: center; }
#container #content form .removeRow {
  position: relative;
  top: -5.1em;
  float: left;
}
#container #content form #no-relative.removeRow { position: static; }
#container #content form .submitRow {
  text-align: center;
  margin-top: 1em;
}
#container #content form label {
  text-align: right;
  margin-right: 10px;
  min-width: 7em;
  line-height: 2em;
  font-style: normal;
}
#container #content form th {
  text-align: right;
  margin-right: 10px;
  min-width: 7em;
  line-height: 2em;
  font-style: normal;
}
#container #content form table.CollectionFieldsTable th { text-align: left; }
#container #content ul.ui-tabs-nav li.ui-state-hover a { border-bottom: none; }
#container #content ul.ui-tabs-nav li.ui-state-hover a:hover { border-bottom: none; }
#container #content .pagination {
  width: 60%;
  text-align: center;
  margin: 1em 0;
}
#container #content .pagination .page {
  border: 1px solid #cccccc;
  padding: 0 6px;
  line-height: 18px;
  margin-left: 2px;
}
#container #content .pagination .prev {
  background: transparent url(../img/prev_bg.jpg) top left no-repeat;
  font-size: 92%;
  height: 18px;
  width: 78px;
  float: left;
  display: block;
  padding: 2px 0 0 8px;
  margin-right: 1em;
  text-align: left;
}
#container #content .pagination .next {
  background: transparent url(../img/next_bg.jpg) top right no-repeat;
  font-size: 92%;
  height: 18px;
  width: 78px;
  float: right;
  display: block;
  padding: 2px 4px;
  margin-left: 1em;
  text-align: right;
}
#container #content .pagination .current {
  background-color: #81a2cc;
  border-color: #81a2cc;
  color: white;
}
#container #content .pagination a:hover { border-bottom: none; }
#container #content .pagination .disabled { color: #cccccc; }
#container #content .collectionState h3 {
  color: #d1975a;
  font-size: 1.3em;
  line-height: 2em;
  padding-left: 1em;
  margin: 2px;
}
#container #content .collectionState ul {
  padding: 0 1em 0 0;
  margin: 0;
  list-style: none;
}
#container #content .collectionState ul a {
  color: #d1975a;
  text-decoration: underline;
}
#container #content .collectionState ul li {
  padding-left: 4.5em;
  margin-top: 2em;
  background-position: 10px top;
  background-repeat: no-repeat;
}
#container #content .collectionState ul li p {
  padding-left: 1em;
  line-height: 1.5em;
  margin: 0.5em;
}
#container #content .collectionState ul li form { padding: 0.5em 1.5em; }
#container #content .collectionState ul h4 {
  font-weight: bold;
  border-bottom: 1px solid #cccccc;
  line-height: 1.5em;
}
#container #content .collectionState ul h4 a {
  color: #717171;
  text-decoration: none;
}
#container #content .collectionState ul li.finished { background-image: url(../img/step-done.png); }
#container #content .collectionState ul li.unfinished { background-image: url(../img/step-undone.png); }
#container #content .collectionState ol {
  padding: 0 1em 0 0;
  margin: 0;
  list-style: none;
}
#container #content .collectionState ol a {
  color: #d1975a;
  text-decoration: underline;
}
#container #content .collectionState ol li {
  padding-left: 4.5em;
  margin-top: 2em;
  background-position: 10px top;
  background-repeat: no-repeat;
}
#container #content .collectionState ol li p {
  padding-left: 1em;
  line-height: 1.5em;
  margin: 0.5em;
}
#container #content .collectionState ol li form { padding: 0.5em 1.5em; }
#container #content .collectionState ol h4 {
  font-weight: bold;
  border-bottom: 1px solid #cccccc;
  line-height: 1.5em;
}
#container #content .collectionState ol h4 a {
  color: #717171;
  text-decoration: none;
}
#container #content .collectionState ol li.finished { background-image: url(../img/step-done.png); }
#container #content .collectionState ol li.unfinished { background-image: url(../img/step-undone.png); }
#container #content .collectionState #collection-steps li.stepOne { background-image: url(../img/step-one.png); }
#container #content .collectionState #collection-steps li.stepTwo { background-image: url(../img/step-two.png); }
#container #content .collectionState #collection-steps li.stepThree { background-image: url(../img/step-three.png); }
#container #content .collectionState #collection-steps li.stepFour { background-image: url(../img/step-four.png); }
#container #content .listing {
  width: 80%;
  background-color: #ffffff;
}
#container #content .listing caption {
  font-style: italic;
  line-height: 3em;
}
#container #content .listing thead { border: 1px solid #cccccc; }
#container #content .listing tbody {
  border: 1px solid #cccccc;
  padding: 5px;
}
#container #content .listing th {
  line-height: 2em;
  background-color: #dae6f2;
}
#container #content .listing tr.even td { background-color: #f3f3f3; }
#container #content .listing td {
  line-height: 1.5em;
  padding: 5px;
}
#container #content .crawlermapping th { padding-right: 1em; }
#container #content ul { list-style-type: square; }
#container #content ol { list-style-type: decimal; }
#container #content ul { padding-left: 2em; }
#container #content ul li { line-height: 1.5em; }
#container #content ul li a:hover {
  border-bottom: 1px dotted;
  color: #004080;
}
#container #content ol { padding-left: 2em; }
#container #content ol li { line-height: 1.5em; }
#container #content ol li a:hover {
  border-bottom: 1px dotted;
  color: #004080;
}
#container #content ul.actions { margin-top: 2em; }
#container #content ul.actions li {
  margin: 5px;
  cursor: pointer;
  text-align: center;
  display: inline;
}
#container #content ul.actions li a {
  border: 1px solid #cccccc;
  width: 100%;
  padding: 5px 6px;
  background: #ededed;
  border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
  -moz-box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
  box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
  font-size: 1em;
  text-shadow: 1px 1px 0 white;
}
#container #content ul.actions li a:hover {
  background: transparent;
  border-bottom: 1px dotted;
}
#container #content ul.actions li input {
  border: 1px solid #cccccc;
  width: 100%;
  padding: 5px 6px;
  background: #ededed;
  border-radius: 2px;
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  -webkit-box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
  -moz-box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
  box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
  font-size: 1em;
  text-shadow: 1px 1px 0 white;
}
#container #content ul.actions li input:hover {
  background: transparent;
  border-bottom: 1px dotted;
}
#container #content ul.actions li input { width: auto; }
#container #content ul.actions li.disabled a {
  background-color: #dfdfdf;
  color: gray;
}
#container #content ul.actions input {
  background: transparent;
  border: none;
  color: #6c98bd;
}
#container #content ul.actions:hover {
  color: #004080;
  cursor: hand;
}
#container #content ul.messages {
  list-style: none;
  padding: 0;
  margin: 0.5em 0;
}
#container #content ul.messages li { padding: 0.5em; }
#container #content ul.messages li.success {
  background-color: #deffda;
  border: 1px solid #68e157;
}
#container #content ul.messages li.warning {
  background-color: #ffdd55;
  border: 1px solid #ffaa00;
  color: black;
}
#container #content ul.messages li.error {
  background-color: #ff4848;
  border: 1px solid red;
  color: white;
}
#container #content dt { font-weight: bold; }
#container #content dd { padding: 0.5em 0 1em 2em; }
#container #content .centered { text-align: center; }
#container #content #item-deleted {
  padding: 10px;
  color: white;
  background: #ff4848;
}
#container #content .CollectionFields { margin-bottom: 50px; }
#container #content table { margin-bottom: 10px; }
#container #left-sidebar {
  display: inline;
  float: left;
  width: 12%;
  padding: 20px 20px 0;
}
#container #left-sidebar h3 {
  font-size: 1.3em;
  margin: 0 0 1em 0;
}
#container #left-sidebar .menu { margin-bottom: 20px; }
#container #left-sidebar .menu li {
  margin: 5px;
  border: 1px solid #cccccc;
  cursor: pointer;
  padding: 5px 6px;
  text-align: center;
  background: #ededed;
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  border-radius: 2px;
  -webkit-box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
  -moz-box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
  box-shadow: 1px 1px 2px rgba(149, 149, 149, 0.5);
}
#container #left-sidebar .menu li a {
  width: 100%;
  text-shadow: 1px 1px 0 white;
  font-size: 1em;
}
#container #left-sidebar .menu li a:hover { border: 0 solid white; }
#container #left-sidebar .menu li:hover {
  background: #ededed;
  color: #004080;
}
#container #left-sidebar ul li { font-size: 1.2em; }
#container #left-sidebar ul ul li { font-size: 1.2em; }
#container #footer {
  clear: both;
  background: #dddddd;
  text-align: center;
  padding: 20px;
  height: 1%;
  border-top: 2px solid #cccccc;
}
li a:hover { border: none; }
.required { font-weight: bold; }
tr.required th { font-weight: bold; }
.error { color: red; }
.errorlist {
  border: 1px solid red;
  background: #ff4848;
  padding: 5px;
  color: white;
  font-weight: bold;
}
.mapping_field input { max-width: 150px; }
.mapping_field { margin-bottom: 10px; }
.mapping_field p { margin: 0px !important; }
.code { display: inline; }
a.changeLink {
  background: transparent url("../img/editlink_icon.png") no-repeat right top;
  margin-left: 5px;
  padding-right: 20px;
}
