{% load i18n %}
{% if item_list %}
    <a href="#" class="hidden">{% trans "Hidden items" %}</a>
    {% regroup item_list by collection as item_list_grouped %}
    <ul class="hidden">
    {% for items_in_collection in item_list_grouped %}
        <li><span>{{ items_in_collection.grouper }}</span>
        <ul>
        {% for item in items_in_collection.list %}
            <li>
            <a href="{{ item.get_absolute_url }}"> {{ item }}</a>
            </li>
        {% endfor %}
        </ul>
        </li>
    {% endfor %}
    </ul>
{% endif %}
