{% extends "manage/base.html" %}

{% load i18n breadcrumbs generic_delete content_delete %}

{% block breadcrumbs %}
  {% breadcrumbs "Blocks:../" placed_block:. %}
{% endblock %}

{% block content %}
  <h2>{% trans "Block detail" %}</h2>
  <ul>
   <li><label>{% trans "Name" %}</label>: {{ placed_block.name }}</li>
   <li><label>{% trans "Place" %}</label>: {{ placed_block.placed_at }}</li>
   <li><label>{% trans "Config" %}</label>:
   <pre>{{ placed_block.config }}</pre></li>
  </ul> 

  <ul class="actions">
    <li><a href="{% url player.block.views.block_edit placed_block.id %}">{% trans "Edit block" %}</a></li>
    {% url block_list as next_url %}
    {% generic_delete placed_block next_url "Delete block" %}
  </ul>

{% endblock %}