{% extends "data/data_wizard.html" %}

{% load i18n %}

{% block wizardpretitle %}
<ul class="messages">
  <li class="warning">
    {% blocktrans %}
    Note: these thresholds will be modified in every collection associated with the collection {{ collection_code }}
    {% endblocktrans %}
  </li>
</ul>
{% endblock %}
