{% extends "block.html" %}

{% load inlinetrans %}

{% block blocktitle %}{% endblock %}

{% block blockbody %}
<nav>
  <ul>
    <li>{% itrans "Home" %}</li>
    <li>{% itrans "News" %}</li>
    <li>{% itrans "Contact us" %}</li>
  </ul>
</nav>
{% endblock %}