{% extends "base.html" %}

{% load inlinetrans %}

{% block content %}
<h2>{% itrans "Item detail" %}</h2>

<h3>{{ item }}</h3>

<dl>
  <dt>{% itrans "Item data as python dictionary" %}:</dt>
  <dd class="itemData">{{ item.data }}</dd>
</dl>
{% endblock %}